Struct bitcoin_block::BlockHeader
source · pub struct BlockHeader {
pub n_version: i32,
pub hash_prev_block: u256,
pub hash_merkle_root: u256,
pub n_time: u32,
pub n_bits: u32,
pub n_nonce: u32,
}Expand description
| Nodes collect new transactions into a block, | hash them into a hash tree, and scan through | nonce values to make the block’s hash satisfy | proof-of-work requirements. | | When they solve the proof-of-work, they | broadcast the block to everyone and the block | is added to the block chain. | | The first transaction in the block is | a special one that creates a new coin owned by | the creator of the block. |
Fields
n_version: i32— header —
hash_prev_block: u256hash_merkle_root: u256n_time: u32n_bits: u32n_nonce: u32Implementations