pub struct FlatFileSeq {
    pub dir: PathBuf,
    pub prefix: *const u8,
    pub chunk_size: usize,
}
| FlatFileSeq represents a sequence | of numbered files storing raw data. | This class facilitates access to and | efficient management of these files. |

Fields

dir: PathBufprefix: *const u8chunk_size: usize

Implementations

| Constructor | | ———– | @param dir | | The base directory that all files live | in. | ––––– | @param prefix | | A short prefix given to all file names. | ––––– | @param chunk_size | | Disk space is pre-allocated in multiples | of this amount. |

| Get the name of the file at the given position. |

| Open a handle to the file at the given | position. |

| Allocate additional space in a file | after the given starting position. | The amount allocated will be the minimum | multiple of the sequence chunk size | greater than add_size. | | ———– | @param[in] pos | | The starting position that bytes will | be allocated after. | ––––– | @param[in] add_size | | The minimum number of bytes to be allocated. | ––––– | @param[out] out_of_space | | Whether the allocation failed due to | insufficient disk space. | | ———– | @return | | The number of bytes successfully allocated. |

| Commit a file to disk, and optionally | truncate off extra pre-allocated bytes | if final. | | ———– | @param[in] pos | | The first unwritten position in the | file to be flushed. | ––––– | @param[in] finalize | | True if no more data will be written to | this file. | | ———– | @return | | true on success, false on failure. |